<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>CryptoDoc</name>
    <message>
        <source>Container is not open</source>
        <translation>Контейнер не открыт</translation>
    </message>
    <message>
        <source>Container is encrypted</source>
        <translation>Контейнер зашифрован</translation>
    </message>
    <message>
        <source>Failed to add file</source>
        <translation>Неудачное добавление файла</translation>
    </message>
    <message>
        <source>Failed to calculate digest</source>
        <translation>Неудачное вычисление хэша</translation>
    </message>
    <message>
        <source>Key already exists</source>
        <translation>Адресат уже добавлен</translation>
    </message>
    <message>
        <source>Failed to add key</source>
        <translation>Неудачное добавление ключа</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation>Внутренняя ошибка</translation>
    </message>
    <message>
        <source>Failed decrypt data</source>
        <translation>Неудачная расшифровка данных</translation>
    </message>
    <message>
        <source>Failed to create temporary files&lt;br /&gt;%1</source>
        <translation>Неудачное создание временных файлов&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>Failed to read decrypted data</source>
        <translation>Неудачное чтение расшифрованных данных</translation>
    </message>
    <message>
        <source>Failed to encrypt data</source>
        <translation>Неудачная зашифровка данных</translation>
    </message>
    <message>
        <source>Failed to open crypted document</source>
        <translation>Открытие зашифрованного файла прошла неуспешно</translation>
    </message>
    <message>
        <source>Failed to remove file</source>
        <translation>Неудачное удаление файла</translation>
    </message>
    <message>
        <source>Failed to remove key</source>
        <translation>Неудачное удаление ключа</translation>
    </message>
    <message>
        <source>Container is not crypted</source>
        <translation>Контейнер незашифрован</translation>
    </message>
    <message>
        <source>Failed to save encrpyted file</source>
        <translation>Неудачное сохранение зашифрованного файла</translation>
    </message>
    <message>
        <source>Document not open</source>
        <translation>Документ не открыт</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Неудачное сохранение файла</translation>
    </message>
    <message>
        <source>You do not have the key to decrypt this document</source>
        <translation>У вас отсутствует ключ для расшифровки документа</translation>
    </message>
    <message>
        <source>No keys specified</source>
        <translation>Не выбран ни один ключ</translation>
    </message>
    <message>
        <source>Failed to save file &apos;%1&apos;</source>
        <translation>Неудачное сохранение файла &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Failed to encrypt data.&lt;br /&gt;File does not exsist %1</source>
        <translation>Зашифрировка данных неудалась&lt;br /&gt;Выбраный файл не существует %1</translation>
    </message>
</context>
<context>
    <name>KeyAddDialog</name>
    <message>
        <source>Certificates (*.pem *.cer *.crt)</source>
        <translation>Сертификаты (*.pem *.crt *.cer)</translation>
    </message>
    <message>
        <source>Failed to open certifiacte</source>
        <translation>Открытые сертификата неуспешно</translation>
    </message>
    <message>
        <source>Failed to read certificate</source>
        <translation>Чтение сертификата неуспешно</translation>
    </message>
    <message>
        <source>This certificate is not usable for crypting</source>
        <translation>Данным сертификатом нельзя шифровать</translation>
    </message>
    <message>
        <source>Social security number is not valid!</source>
        <translation>Личной код некорректен!</translation>
    </message>
    <message>
        <source>Add Recipient</source>
        <translation>Добавить сертификат</translation>
    </message>
    <message>
        <source>SK Certificates</source>
        <translation>SK сертификаты</translation>
    </message>
    <message>
        <source>Personal code:</source>
        <translation>Личный код:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Владелец</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Выдавший</translation>
    </message>
    <message>
        <source>Expiry date</source>
        <translation>Дата окончания</translation>
    </message>
    <message>
        <source>Add cert</source>
        <translation>Добавить сертификат</translation>
    </message>
    <message>
        <source>Used certificates</source>
        <translation>Использованные сертификаты</translation>
    </message>
    <message>
        <source>Add cert from card</source>
        <translation>Добавить сертификат с карты</translation>
    </message>
    <message>
        <source>Add cert from file</source>
        <translation>Добавить сертификат из файла</translation>
    </message>
    <message>
        <source>Company name:</source>
        <translation>Учреждение:</translation>
    </message>
    <message>
        <source>Empty result</source>
        <translation>Ничего не найдено</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
        <translation>Вы уверены, что хотите использовать для зашифровки сертификат, который просрочился %1?&lt;br /&gt;В случае, когда расшифровщик обновит сертификат, расшифровка будет невозможна.</translation>
    </message>
    <message>
        <source>Keys added successfully</source>
        <translation>Адресат успешно добавлен</translation>
    </message>
    <message>
        <source>Failed to add keys</source>
        <translation>Неудачное добавление ключа</translation>
    </message>
</context>
<context>
    <name>KeyDialog</name>
    <message>
        <source>Crypt method</source>
        <translation>Метод шифровки</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Истекает</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Выдавший</translation>
    </message>
    <message>
        <source>Crypt recipient</source>
        <translation>Зашифровать получателю</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Атрибут</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>Показать сертификат</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
</context>
<context>
    <name>KeyWidget</name>
    <message>
        <source>Show details</source>
        <translation>Показать детали</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>LdapSearch</name>
    <message>
        <source>Failed to init ldap</source>
        <translation>Инициализация LDAP неудалась</translation>
    </message>
    <message>
        <source>Failed to init ldap search</source>
        <translation>Инициализация поиска LDAP неуспешна</translation>
    </message>
    <message>
        <source>Failed to get result</source>
        <translation>Получение ответа неуспешно</translation>
    </message>
    <message>
        <source>Empty result</source>
        <translation>Ничего не найдено</translation>
    </message>
    <message>
        <source>LDAP server is unavailable.</source>
        <translation>Не могу подключиться к LDAP серверу.</translation>
    </message>
    <message>
        <source>Error Code: %1 (%2)</source>
        <translation>Код ошибки:%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Documents (*.cdoc)</source>
        <translation>Документы(*.cdoc)</translation>
    </message>
    <message>
        <source>Container contains file with same name, ovewrite?</source>
        <translation>В контейнере уже есть файлы с таким именем, перезаписать?</translation>
    </message>
    <message>
        <source>Select documents</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <source>This container contains signature! Open with QDigiDocClient?</source>
        <translation>Это файл с дигитальной подписью!
Открыть c помощью Digidoc?</translation>
    </message>
    <message>
        <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
        <translation>%1 уже есть.&lt;br /&gt;Желаете заменить?</translation>
    </message>
    <message>
        <source>Open container</source>
        <translation>Открыть контейнер</translation>
    </message>
    <message>
        <source>Select folder where files will be stored</source>
        <translation>Выберите папку куда будут сохранены файлы</translation>
    </message>
    <message>
        <source>Container: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Контейнер: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Decrypt</source>
        <translation>Расшифровать</translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation>Зашифровать</translation>
    </message>
    <message>
        <source>Loading data</source>
        <translation>Загружаю данные</translation>
    </message>
    <message>
        <source>No card in reader</source>
        <translation>В считывателе нет карты</translation>
    </message>
    <message>
        <source>Error code: %1</source>
        <translation>Код ошибки:%1</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>I want to:</source>
        <translation>Я желаю:</translation>
    </message>
    <message>
        <source>Yes, I will use ID-card certificate only for secure transfer</source>
        <translation>Да, я использую ID-карту только для безопасной передачи данных</translation>
    </message>
    <message>
        <source>Container:</source>
        <translation>Контейнер:</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;email&quot;&gt;Послать контейнер на эл. почту&lt;/a&gt;&lt;br /&gt;
&lt;a href=&quot;browse&quot;&gt;Показать расположение контейнера&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt; &lt;a href=&quot;saveAll&quot;&gt;Save files to disk&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addFile&quot;&gt;Добавить файл&lt;/a&gt; &lt;a href=&quot;saveAll&quot;&gt;Сохранить файлы&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addRecipient&quot;&gt;Add recipient&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addRecipient&quot;&gt;Добавить получателя&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <source>Container content:</source>
        <translation>Содержание контейнера:</translation>
    </message>
    <message>
        <source>Keys</source>
        <translation>Ключи</translation>
    </message>
    <message>
        <source>Failed to start process &apos;%1&apos;</source>
        <translation>Создание процесса &apos;%1&apos; неудачно</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
&lt;b&gt;File encryption&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
The purpose of file encryption is to make the data stored in the file unreadable for any unauthorised users.&lt;br /&gt;&lt;br /&gt;
Encryption with ID-card is not ment for long and secure data storage, it is only ment for secure transfering of data over unsecure media.&lt;br /&gt;&lt;br /&gt;
For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search for reciever(s) certificates. Documents are encrypted with public key that is found the certificate.&lt;/p&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Warning&lt;/b&gt;&lt;/font&gt;&lt;br /&gt;&lt;br /&gt;
&lt;b&gt;Encryption is one-way only. Private key needed for decryption is stored only on reciever&apos;s ID-card. Decryption of files is impossible if ID-card is lost or damaged, sertificates are expired or renewed. &lt;/b&gt;
&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
&lt;b&gt;Шифрование файлов&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
Цель шифрования файла - сделать данные нечитаемыми для посторонних лиц.&lt;br /&gt;&lt;br /&gt;
Шифрование сертификатом ID-карты не предназначено для долгосрочного хранения зашифрованных данных или других задач, это лишь метод для передачи файлов по небезопасному каналу связи.&lt;br /&gt;&lt;br /&gt;
Для шифрования файлов используется предоставляемая AS Sertifitseerimiskeskus LDAP-услуга для поиска сертификатов. Файлы шифруются открытым ключом, содержащимся в сертификате. Шифрование является односторонним, для расшифровки необходим персональный ключ сертификата получателя файла, встроенный в его ID-карту.&lt;/p&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;&lt;font color=&quot;red&quot;&gt;&lt;b&gt;ПРЕДУПРЕЖДЕНИЕ:&lt;/b&gt;&lt;/font&gt;&lt;br /&gt;&lt;br /&gt;
&lt;b&gt;Так как сертификат, позволяющий расшифровать данные, встроен только в конкретную ID-карту, то после утери, обновления, истечения срока действия или механического повреждения этой ID-карты расшифровка данных становится технически невозможной.&lt;/b&gt;
&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Encrypt documents</source>
        <translation>Зашифровать документ</translation>
    </message>
    <message>
        <source>View encrypted document content</source>
        <translation>Посмотреть содержание зашифрованного документа</translation>
    </message>
    <message>
        <source>Decrypting</source>
        <translation>Расшифровка</translation>
    </message>
    <message>
        <source>You dont have permissions to write file %1</source>
        <translation>У Вас недостаточно прав, для записи файла %1</translation>
    </message>
    <message>
        <source>Documents (*.cdoc *.CDOC)</source>
        <translation>Документы(*.cdoc *:CDOC)</translation>
    </message>
    <message>
        <source>DigiDoc3 Crypto</source>
        <translation>DigiDoc3 Crypto</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>File does not exists %1</source>
        <translation>Выбраный файл не существует %1</translation>
    </message>
    <message>
        <source>Wrong PIN or PIN is blocked</source>
        <translation>Неправильный PIN или PIN заблокирован</translation>
    </message>
</context>
<context>
    <name>Poller</name>
    <message>
        <source>Authentication certificate is not selected.</source>
        <translation>Сертификат идентификации не выбран.</translation>
    </message>
    <message>
        <source>Failed to login token</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>PIN acquisition canceled.</source>
        <translation>Ввод PIN кода был отменен.</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN заблокирован</translation>
    </message>
    <message>
        <source>Failed to decrypt document</source>
        <translation>Неудачная зашифровка документа</translation>
    </message>
    <message>
        <source>Failed to load PKCS#11 module</source>
        <translation>Неудалось загрузить PKCS#11 модуль</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Select folder</source>
        <translation>Выбрать папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Container default location</source>
        <translation>Расположение контейнера по умолчанию</translation>
    </message>
    <message>
        <source>Same folder</source>
        <translation>Та же папка</translation>
    </message>
    <message>
        <source>Ask container name</source>
        <translation>Спрашивать имя документа</translation>
    </message>
    <message>
        <source>Show encrypting intro</source>
        <translation>Показывать подсказку для шифрования</translation>
    </message>
    <message>
        <source>It is not possible to change the file location. Changes will be valid to new containers only.</source>
        <translation>Невозможно изменить расположение уже открытого конверта. Настройки будут действительны только для новых конвертов.</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
</context>
</TS>
